@@ -31,13 +31,34 @@ class Dumper:
         self.filter = None  # type: flowfilter.TFilter
         self.outfp = outfile  # type: typing.io.TextIO
 
+    def load(self, loader):
+        loader.add_option(
+            "flow_detail", int, 1,
+            """
+            The display detail level for flows in mitmdump: 0 (almost quiet) to 3 (very verbose).
+              0: shortened request URL, response status code, WebSocket and TCP message notifications.
+              1: full request URL with response status code
+              2: 1 + HTTP headers
+              3: 2 + full response content, content of WebSocket and TCP messages.
+            """
+        )
+        loader.add_option(
+            "dumper_default_contentview", str, "auto",
+            "The default content view mode.",
+            choices = [i.name.lower() for i in contentviews.views]
+        )
+        loader.add_option(
+            "dumper_filter", typing.Optional[str], None,
+            "Limit which flows are dumped."
+        )
+
     def configure(self, updated):
-        if "view_filter" in updated:
-            if ctx.options.view_filter:
-                self.filter = flowfilter.parse(ctx.options.view_filter)
+        if "dumper_filter" in updated:
+            if ctx.options.dumper_filter:
+                self.filter = flowfilter.parse(ctx.options.dumper_filter)
                 if not self.filter:
                     raise exceptions.OptionsError(
-                        "Invalid filter expression: %s" % ctx.options.view_filter
+                        "Invalid filter expression: %s" % ctx.options.dumper_filter
                     )
             else:
                 self.filter = None
@@ -61,7 +82,7 @@ class Dumper:
 
     def _echo_message(self, message):
         _, lines, error = contentviews.get_message_content_view(
-            ctx.options.default_contentview,
+            ctx.options.dumper_default_contentview,
             message
         )
         if error:
