@@ -49,7 +49,8 @@ class ActionBar(urwid.WidgetWrap):
     def sig_message(self, sender, message, expire=1):
         if self.prompting:
             return
-        w = urwid.Text(message)
+        cols, _ = self.master.ui.get_cols_rows()
+        w = urwid.Text(self.shorten_message(message, cols))
         self._w = w
         if expire:
             def cb(*args):
@@ -60,6 +61,36 @@ class ActionBar(urwid.WidgetWrap):
     def prep_prompt(self, p):
         return p.strip() + ": "
 
+    def shorten_message(self, msg, max_width):
+        """
+        Shorten message so that it fits into a single line in the statusbar.
+        """
+        if isinstance(msg, tuple):
+            disp_attr, msg_text = msg
+        elif isinstance(msg, str):
+            disp_attr, msg_text = None, msg
+        else:
+            return msg
+        msg_end = "\u2026"  # unicode ellipsis for the end of shortened message
+        prompt = "(more in eventlog)"
+
+        msg_lines = msg_text.split("\n")
+        first_line = msg_lines[0]
+        if len(msg_lines) > 1:
+            # First line of messages with a few lines must end with prompt.
+            line_length = len(first_line) + len(prompt)
+        else:
+            line_length = len(first_line)
+
+        if line_length > max_width:
+            shortening_index = max(0, max_width - len(prompt) - len(msg_end))
+            first_line = first_line[:shortening_index] + msg_end
+        else:
+            if len(msg_lines) == 1:
+                prompt = ""
+
+        return [(disp_attr, first_line), ("warn", prompt)]
+
     def sig_prompt(self, sender, prompt, text, callback, args=()):
         signals.focus.send(self, section="footer")
         self._w = urwid.Edit(self.prep_prompt(prompt), text or "")
@@ -160,9 +191,7 @@ class StatusBar(urwid.WidgetWrap):
             r.append(("heading_key", "H"))
             r.append("eaders]")
         if len(self.master.options.replacements):
-            r.append("[")
-            r.append(("heading_key", "R"))
-            r.append("eplacing]")
+            r.append("[%d replacements]" % len(self.master.options.replacements))
         if creplay.count():
             r.append("[")
             r.append(("heading_key", "cplayback"))
@@ -197,10 +226,8 @@ class StatusBar(urwid.WidgetWrap):
             r.append("[")
             r.append(("heading_key", "u"))
             r.append(":%s]" % self.master.options.stickyauth)
-        if self.master.options.default_contentview != "auto":
-            r.append("[")
-            r.append(("heading_key", "M"))
-            r.append(":%s]" % self.master.options.default_contentview)
+        if self.master.options.console_default_contentview != 'auto':
+            r.append("[contentview:%s]" % (self.master.options.console_default_contentview))
         if self.master.options.has_changed("view_order"):
             r.append("[")
             r.append(("heading_key", "o"))
